@@ -18,7 +18,8 @@ class Response(object):
 		DOCS = {
 			"module":"dev0s.response", 
 			"initialized":True,
-			"description":[], }
+			"description":[], 
+			"chapter":"response", }
 
 		# set log file.
 		#	assign new values with self.log_file.assign(...) to keep it shared across other objects.
@@ -59,9 +60,9 @@ class Response(object):
 		self.log(message=response["message"], log_level=log_level, save=save, required_log_level=required_log_level)
 		if django: 
 			try:
-				response = JsonResponse(response.dict(safe=True))
+				response = JsonResponse(response.dict(safe=True), safe=False)
 			except AttributeError:
-				response = JsonResponse(response)
+				response = JsonResponse(response, safe=False)
 		return response
 	def error(self,
 		# the error message.
@@ -87,9 +88,9 @@ class Response(object):
 			raise ValueError(response["error"])
 		if django: 
 			try:
-				response = JsonResponse(response.dict(safe=True))
+				response = JsonResponse(response.dict(safe=True), safe=False)
 			except AttributeError:
-				response = JsonResponse(response)
+				response = JsonResponse(response, safe=False)
 		return response
 		#
 
@@ -271,14 +272,17 @@ class Response(object):
 		elif (json or safe) and not isinstance(variable, (Dictionary)) and isinstance(variable, object):
 			if isinstance(variable, (Date)):
 				return f'"{variable.raw()}"'
-			elif isinstance(variable, (Integer,Boolean,Version,Bytes,Array,File,ResponseObject)):
+			elif variable.__class__.__name__ in ["Version", "OutputObject"] or isinstance(variable, (Integer,Boolean,Bytes,Array,File,ResponseObject)):
 				return variable.raw()	
 			elif variable in [None, "None"]:
 				return None
 			else:
 				return str(variable)
 		else:
-			return variable
+			if json or safe:
+				return str(variable)
+			else:
+				return variable
 		if isinstance(variable, (dict, Dictionary)):
 			_variable_ = {}
 			for key, value in variable.items():
@@ -290,7 +294,10 @@ class Response(object):
 				_variable_.append(self.serialize(variable=value, json=json))
 			return _variable_
 		else:
-			return variable
+			if json or safe:
+				return str(variable)
+			else:
+				return variable
 		
 		#
 	def response(self, 
@@ -354,7 +361,8 @@ class Parameters(object):
 		DOCS = {
 			"module":"dev0s.response.parameters", 
 			"initialized":True,
-			"description":[], }
+			"description":[], 
+			"chapter":"response", }
 
 		#
 	
